from setuptools import setup

setup(
    name='tremor',
    version=0.1,
    description='Placeholder for private GA package',
    author='Brenainn Moushall',
    author_email='brenainn.moushall@ga.gov.au',
)
